==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MongoDbShardKeyFieldArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.MongoDbShardKeyOrder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a field reference within a MongoDB shard key
 * @property name The name of the field
 * @property order The field ordering
 */
public data class MongoDbShardKeyFieldArgs(
    public val name: Output<String>,
    public val order: Output<Either<String, MongoDbShardKeyOrder>>,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs =
        com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .order(
                order.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [MongoDbShardKeyFieldArgs].
 */
@PulumiTagMarker
public class MongoDbShardKeyFieldArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var order: Output<Either<String, MongoDbShardKeyOrder>>? = null

    /**
     * @param value The name of the field
     */
    @JvmName("fxqwepielcdabfyu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The field ordering
     */
    @JvmName("vdxwsuxpuinauoeh")
    public suspend fun order(`value`: Output<Either<String, MongoDbShardKeyOrder>>) {
        this.order = value
    }

    /**
     * @param value The name of the field
     */
    @JvmName("uvkygukpvavkxvla")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The field ordering
     */
    @JvmName("ywkuevtwnvtqypba")
    public suspend fun order(`value`: Either<String, MongoDbShardKeyOrder>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value The field ordering
     */
    @JvmName("nbonktmoxskrwraa")
    public fun order(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MongoDbShardKeyOrder>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value The field ordering
     */
    @JvmName("dcjcbbhcfjtbjhbh")
    public fun order(`value`: MongoDbShardKeyOrder) {
        val toBeMapped = Either.ofRight<String, MongoDbShardKeyOrder>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    internal fun build(): MongoDbShardKeyFieldArgs = MongoDbShardKeyFieldArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        order = order ?: throw PulumiNullFieldException("order"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datamigration/kotlin/inputs/MongoDbShardKeyFieldArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datamigration.kotlin.inputs

import com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs.builder
import com.pulumi.azurenative.datamigration.kotlin.enums.MongoDbShardKeyOrder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Describes a field reference within a MongoDB shard key
 * @property name The name of the field
 * @property order The field ordering
 */
public data class MongoDbShardKeyFieldArgs(
    public val name: Output<String>,
    public val order: Output<Either<String, MongoDbShardKeyOrder>>,
) : ConvertibleToJava<com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs> {
    override fun toJava(): com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs =
        com.pulumi.azurenative.datamigration.inputs.MongoDbShardKeyFieldArgs.builder()
            .name(name.applyValue({ args0 -> args0 }))
            .order(
                order.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [MongoDbShardKeyFieldArgs].
 */
@PulumiTagMarker
public class MongoDbShardKeyFieldArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var order: Output<Either<String, MongoDbShardKeyOrder>>? = null

    /**
     * @param value The name of the field
     */
    @JvmName("mriplmojstktvxkf")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The field ordering
     */
    @JvmName("tagjoekxuocotrdr")
    public suspend fun order(`value`: Output<Either<String, MongoDbShardKeyOrder>>) {
        this.order = value
    }

    /**
     * @param value The name of the field
     */
    @JvmName("ktcavrnhflfqvhjb")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The field ordering
     */
    @JvmName("olpmcgrmjemwlctm")
    public suspend fun order(`value`: Either<String, MongoDbShardKeyOrder>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value The field ordering
     */
    @JvmName("fcckxwbdainyxofk")
    public fun order(`value`: String) {
        val toBeMapped = Either.ofLeft<String, MongoDbShardKeyOrder>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    /**
     * @param value The field ordering
     */
    @JvmName("opgwqfyioyjntyhv")
    public fun order(`value`: MongoDbShardKeyOrder) {
        val toBeMapped = Either.ofRight<String, MongoDbShardKeyOrder>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.order = mapped
    }

    internal fun build(): MongoDbShardKeyFieldArgs = MongoDbShardKeyFieldArgs(
        name = name ?: throw PulumiNullFieldException("name"),
        order = order ?: throw PulumiNullFieldException("order"),
    )
}
